==> qtjambi-multimedia-debuginfo-linux-x64-6.5.6.jar: sources/QtJambiMultimedia/metainfo.cpp <==
#include <QtJambi/MetaInfo>


#if defined(Q_OS_ANDROID)
void initialize_meta_info_QtMultimedia();
#endif
void initialize_meta_info_QAudio();
void initialize_meta_info_QAudioBuffer();
void initialize_meta_info_QAudioDecoder();
void initialize_meta_info_QAudioDevice();
void initialize_meta_info_QAudioFormat();
void initialize_meta_info_QAudioInput();
void initialize_meta_info_QAudioOutput();
void initialize_meta_info_QAudioSink();
void initialize_meta_info_QAudioSource();
void initialize_meta_info_QCamera();
void initialize_meta_info_QCameraDevice();
void initialize_meta_info_QCameraFormat();
void initialize_meta_info_QImageCapture();
void initialize_meta_info_QMediaCaptureSession();
void initialize_meta_info_QMediaDevices();
void initialize_meta_info_QMediaFormat();
void initialize_meta_info_QMediaMetaData();
void initialize_meta_info_QMediaPlayer();
void initialize_meta_info_QMediaRecorder();
void initialize_meta_info_QMediaTimeRange();
void initialize_meta_info_QMediaTimeRange_Interval();
void initialize_meta_info_QScreenCapture();
void initialize_meta_info_QSoundEffect();
void initialize_meta_info_QVideoFrame();
void initialize_meta_info_QVideoFrame_PaintOptions();
void initialize_meta_info_QVideoFrameFormat();
void initialize_meta_info_QVideoSink();
void initialize_meta_info_QWaveDecoder();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.multimedia")

#if defined(Q_OS_ANDROID)
    initialize_meta_info_QtMultimedia();
#endif
    initialize_meta_info_QAudio();
    initialize_meta_info_QAudioBuffer();
    initialize_meta_info_QAudioDecoder();
    initialize_meta_info_QAudioDevice();
    initialize_meta_info_QAudioFormat();
    initialize_meta_info_QAudioInput();
    initialize_meta_info_QAudioOutput();
    initialize_meta_info_QAudioSink();
    initialize_meta_info_QAudioSource();
    initialize_meta_info_QCamera();
    initialize_meta_info_QCameraDevice();
    initialize_meta_info_QCameraFormat();
    initialize_meta_info_QImageCapture();
    initialize_meta_info_QMediaCaptureSession();
    initialize_meta_info_QMediaDevices();
    initialize_meta_info_QMediaFormat();
    initialize_meta_info_QMediaMetaData();
    initialize_meta_info_QMediaPlayer();
    initialize_meta_info_QMediaRecorder();
    initialize_meta_info_QMediaTimeRange();
    initialize_meta_info_QMediaTimeRange_Interval();
    initialize_meta_info_QScreenCapture();
    initialize_meta_info_QSoundEffect();
    initialize_meta_info_QVideoFrame();
    initialize_meta_info_QVideoFrame_PaintOptions();
    initialize_meta_info_QVideoFrameFormat();
    initialize_meta_info_QVideoSink();
    initialize_meta_info_QWaveDecoder();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}

==> qtjambi-multimedia-debuginfo-linux-x64-6.7.0.jar: sources/QtJambiMultimedia/metainfo.cpp <==
#include <QtJambi/MetaInfo>


#if defined(Q_OS_ANDROID)
void initialize_meta_info_QtMultimedia();
#endif
void initialize_meta_info_QAudioBuffer();
void initialize_meta_info_QAudioDecoder();
void initialize_meta_info_QAudioDevice();
void initialize_meta_info_QAudioFormat();
void initialize_meta_info_QAudioInput();
void initialize_meta_info_QAudioOutput();
void initialize_meta_info_QAudioSink();
void initialize_meta_info_QAudioSource();
void initialize_meta_info_QCamera();
void initialize_meta_info_QCameraDevice();
void initialize_meta_info_QCameraFormat();
void initialize_meta_info_QCapturableWindow();
void initialize_meta_info_QImageCapture();
void initialize_meta_info_QMediaCaptureSession();
void initialize_meta_info_QMediaDevices();
void initialize_meta_info_QMediaFormat();
void initialize_meta_info_QMediaMetaData();
void initialize_meta_info_QMediaPlayer();
void initialize_meta_info_QMediaRecorder();
void initialize_meta_info_QMediaTimeRange();
void initialize_meta_info_QMediaTimeRange_Interval();
void initialize_meta_info_QScreenCapture();
void initialize_meta_info_QSoundEffect();
void initialize_meta_info_QVideoFrame();
void initialize_meta_info_QVideoFrame_PaintOptions();
void initialize_meta_info_QVideoFrameFormat();
void initialize_meta_info_QVideoSink();
void initialize_meta_info_QWaveDecoder();
void initialize_meta_info_QWindowCapture();
void initialize_meta_info_QtAudio();
void initialize_meta_info_QtVideo();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.multimedia")

#if defined(Q_OS_ANDROID)
    initialize_meta_info_QtMultimedia();
#endif
    initialize_meta_info_QAudioBuffer();
    initialize_meta_info_QAudioDecoder();
    initialize_meta_info_QAudioDevice();
    initialize_meta_info_QAudioFormat();
    initialize_meta_info_QAudioInput();
    initialize_meta_info_QAudioOutput();
    initialize_meta_info_QAudioSink();
    initialize_meta_info_QAudioSource();
    initialize_meta_info_QCamera();
    initialize_meta_info_QCameraDevice();
    initialize_meta_info_QCameraFormat();
    initialize_meta_info_QCapturableWindow();
    initialize_meta_info_QImageCapture();
    initialize_meta_info_QMediaCaptureSession();
    initialize_meta_info_QMediaDevices();
    initialize_meta_info_QMediaFormat();
    initialize_meta_info_QMediaMetaData();
    initialize_meta_info_QMediaPlayer();
    initialize_meta_info_QMediaRecorder();
    initialize_meta_info_QMediaTimeRange();
    initialize_meta_info_QMediaTimeRange_Interval();
    initialize_meta_info_QScreenCapture();
    initialize_meta_info_QSoundEffect();
    initialize_meta_info_QVideoFrame();
    initialize_meta_info_QVideoFrame_PaintOptions();
    initialize_meta_info_QVideoFrameFormat();
    initialize_meta_info_QVideoSink();
    initialize_meta_info_QWaveDecoder();
    initialize_meta_info_QWindowCapture();
    initialize_meta_info_QtAudio();
    initialize_meta_info_QtVideo();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}
